# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Protocol(str, Enum):
    """
    Enum class for NSB2023Protocol.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    N_2119__TRAINING_AND_QUAL = '2119 - Training and qualification of animal users'
    N_2201__INTERROGATING_PRO = '2201 - Interrogating projections and gene '
    N_2202__TESTING_AA_VS_IN = '2202 - Testing AAVs in Parkinson\'s mouse models'
    N_2204__PRIMARY_NEURON_AN = '2204 - Primary neuron and brain slice '
    N_2205__OPTIMIZATION_AND = '2205 - Optimization and validation of viral vectors'
    N_2207__IN__VITRO__BRAIN = '2207 - In Vitro Brain Stimulation'
    N_2212__INVESTIGATING__BR = '2212 - Investigating Brain States'
    N_2301__TESTING_OF_ENHANC = '2301 - Testing of enhancers and AAV gene therapy vectors'
    N_2304__NEUROSURGERY__BEH = '2304 - Neurosurgery & Behavior Training Protocol'
    N_2305__IN__VIVO__BRAIN = '2305 - In Vivo Brain Stimulation'
    N_2306__PATCH_SEQ_CHARACT = '2306 - Patch-seq characterization of mouse neurons in acute brain slices for cross-species comparison studies'
    N_2307__DISSECTING_THE_NE = '2307 - Dissecting the neural circuits of adaptive control of behavior'
    N_2308__INDUCTION_OF__IMM = '2308 - Induction of Immune Memory'
    N_2401__THE_USE_OF_MICE_F = '2401 - The use of mice for the development of biological recorders'
    N_2402__BRAIN__OBSERVATOR = '2402 - Brain Observatory Optical Physiology'
    N_2403__ELECTROPHYSIOLOGY = '2403 - Electrophysiology Mindscope Phase 4'
    N_2405__ANALYSIS_OF__INTE = '2405 - Analysis of Integrated Neuronal Phenotypes'
    N_2406__CHARACTERIZATION = '2406 - Characterization of mouse and viral genetic tools'
    N_2410__VALIDATION_OF_BRA = '2410 - Validation of brain cell type enhancer AAV vectors in rats'
    N_2412__CIRCUIT_TRACING_A = '2412 - Circuit tracing and optical physiology of mouse cortex'
    N_2413__NEUROPHYSIOLOGY_O = '2413 - Neurophysiology of Naturalistic Learning'
    N_2414__ELECTROPHYSIOLOGI = '2414 - Electrophysiological and optical interrogation of brain-wide neural circuits in the mouse'
    N_2415__OPTOPHYSIOLOGICAL = '2415 - Optophysiological analysis of brain-wide neural circuits in the mouse'
    N_2416__ANATOMICAL_ANALYS = '2416 - Anatomical analysis of brain-wide neural circuits in the mouse'
    N_2417__CHARACTERIZATION = '2417 - Characterization of transcriptomic cell type activation and their molecular adaptations that occur during psychedelic, antidepressants, and antipsychotic drug use'
    N_2418__IN__VITRO__SINGLE = '2418 - In Vitro Single Cell Characterization'
    N_2427__OPEN_SCOPE__MINDS = '2427 - OpenScope Mindscope animal protocol for Optical Physiology and Neuropixel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Protocol from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

# flake8: noqa

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.5"

# import apis into sdk package
from aind_sharepoint_service_async_client.api.default_api import DefaultApi
from aind_sharepoint_service_async_client.api.healthcheck_api import HealthcheckApi

# import ApiClient
from aind_sharepoint_service_async_client.api_response import ApiResponse
from aind_sharepoint_service_async_client.api_client import ApiClient
from aind_sharepoint_service_async_client.configuration import Configuration
from aind_sharepoint_service_async_client.exceptions import OpenApiException
from aind_sharepoint_service_async_client.exceptions import ApiTypeError
from aind_sharepoint_service_async_client.exceptions import ApiValueError
from aind_sharepoint_service_async_client.exceptions import ApiKeyError
from aind_sharepoint_service_async_client.exceptions import ApiAttributeError
from aind_sharepoint_service_async_client.exceptions import ApiException

# import models into sdk package
from aind_sharepoint_service_async_client.models.http_validation_error import HTTPValidationError
from aind_sharepoint_service_async_client.models.health_check import HealthCheck
from aind_sharepoint_service_async_client.models.las_bctype import LASBctype
from aind_sharepoint_service_async_client.models.las_deliverylocation import LASDeliverylocation
from aind_sharepoint_service_async_client.models.las_doseroute import LASDoseroute
from aind_sharepoint_service_async_client.models.las_icvlims import LASIcvlims
from aind_sharepoint_service_async_client.models.las_icvroute1 import LASIcvroute1
from aind_sharepoint_service_async_client.models.las_icvroute2 import LASIcvroute2
from aind_sharepoint_service_async_client.models.las_icvroute3 import LASIcvroute3
from aind_sharepoint_service_async_client.models.las_icvroute4 import LASIcvroute4
from aind_sharepoint_service_async_client.models.las_icvroute5 import LASIcvroute5
from aind_sharepoint_service_async_client.models.las_limsproject import LASLimsproject
from aind_sharepoint_service_async_client.models.las_limsworkflow import LASLimsworkflow
from aind_sharepoint_service_async_client.models.las_limsworkflow2 import LASLimsworkflow2
from aind_sharepoint_service_async_client.models.las_postfix import LASPostfix
from aind_sharepoint_service_async_client.models.las_projectid import LASProjectid
from aind_sharepoint_service_async_client.models.las_protocol import LASProtocol
from aind_sharepoint_service_async_client.models.las_reqpro1 import LASReqpro1
from aind_sharepoint_service_async_client.models.las_reqpro2 import LASReqpro2
from aind_sharepoint_service_async_client.models.las_reqpro3 import LASReqpro3
from aind_sharepoint_service_async_client.models.las_reqpro4 import LASReqpro4
from aind_sharepoint_service_async_client.models.las_requeststatus2 import LASRequeststatus2
from aind_sharepoint_service_async_client.models.las_roeye1 import LASRoeye1
from aind_sharepoint_service_async_client.models.las_roeye2 import LASRoeye2
from aind_sharepoint_service_async_client.models.las_roeye3 import LASRoeye3
from aind_sharepoint_service_async_client.models.las_roeye4 import LASRoeye4
from aind_sharepoint_service_async_client.models.las_roeye5 import LASRoeye5
from aind_sharepoint_service_async_client.models.las_rolims import LASRolims
from aind_sharepoint_service_async_client.models.las_rosop import LASRosop
from aind_sharepoint_service_async_client.models.las_rowhere import LASRowhere
from aind_sharepoint_service_async_client.models.las_species import LASSpecies
from aind_sharepoint_service_async_client.models.las_tam_frequency import LASTamFrequency
from aind_sharepoint_service_async_client.models.las_tcprep import LASTcprep
from aind_sharepoint_service_async_client.models.las_tctiss import LASTctiss
from aind_sharepoint_service_async_client.models.las_tmp_frequency import LASTmpFrequency
from aind_sharepoint_service_async_client.models.las_wheretoobtainsubstance_icv import LASWheretoobtainsubstanceIcv
from aind_sharepoint_service_async_client.models.las2020_list import Las2020List
from aind_sharepoint_service_async_client.models.lightcycle import Lightcycle
from aind_sharepoint_service_async_client.models.nsb2019_after1_st_injection import NSB2019After1StInjection
from aind_sharepoint_service_async_client.models.nsb2019_after2_nd_injection import NSB2019After2NdInjection
from aind_sharepoint_service_async_client.models.nsb2019_contusion import NSB2019Contusion
from aind_sharepoint_service_async_client.models.nsb2019_craniotomy_type import NSB2019CraniotomyType
from aind_sharepoint_service_async_client.models.nsb2019_during1_st_injection import NSB2019During1StInjection
from aind_sharepoint_service_async_client.models.nsb2019_during2_nd_injection import NSB2019During2NdInjection
from aind_sharepoint_service_async_client.models.nsb2019_durotomy import NSB2019Durotomy
from aind_sharepoint_service_async_client.models.nsb2019_edema_swelling import NSB2019EdemaSwelling
from aind_sharepoint_service_async_client.models.nsb2019_exudate_severity import NSB2019ExudateSeverity
from aind_sharepoint_service_async_client.models.nsb2019_eye_affected import NSB2019EyeAffected
from aind_sharepoint_service_async_client.models.nsb2019_eye_issue import NSB2019EyeIssue
from aind_sharepoint_service_async_client.models.nsb2019_first_round_inj_iso_level import NSB2019FirstRoundInjIsoLevel
from aind_sharepoint_service_async_client.models.nsb2019_first_round_inj_workstation import NSB2019FirstRoundInjWorkstation
from aind_sharepoint_service_async_client.models.nsb2019_firstroundiontoissue import NSB2019Firstroundiontoissue
from aind_sharepoint_service_async_client.models.nsb2019_firstroundiontonumber import NSB2019Firstroundiontonumber
from aind_sharepoint_service_async_client.models.nsb2019_firstroundnanojectnumber import NSB2019Firstroundnanojectnumber
from aind_sharepoint_service_async_client.models.nsb2019_headpost_type import NSB2019HeadpostType
from aind_sharepoint_service_async_client.models.nsb2019_hematoma import NSB2019Hematoma
from aind_sharepoint_service_async_client.models.nsb2019_hp_durotomy import NSB2019HpDurotomy
from aind_sharepoint_service_async_client.models.nsb2019_hp_iso_level import NSB2019HpIsoLevel
from aind_sharepoint_service_async_client.models.nsb2019_hp_location import NSB2019HpLocation
from aind_sharepoint_service_async_client.models.nsb2019_hp_perferations import NSB2019HpPerferations
from aind_sharepoint_service_async_client.models.nsb2019_hp_work_station import NSB2019HpWorkStation
from aind_sharepoint_service_async_client.models.nsb2019_iacuc_protocol import NSB2019IacucProtocol
from aind_sharepoint_service_async_client.models.nsb2019_implant_id_coverslip_type import NSB2019ImplantIdCoverslipType
from aind_sharepoint_service_async_client.models.nsb2019_inj1_angle import NSB2019Inj1Angle
from aind_sharepoint_service_async_client.models.nsb2019_inj1_hemisphere import NSB2019Inj1Hemisphere
from aind_sharepoint_service_async_client.models.nsb2019_inj1_retsetting import NSB2019Inj1Retsetting
from aind_sharepoint_service_async_client.models.nsb2019_inj1_round import NSB2019Inj1Round
from aind_sharepoint_service_async_client.models.nsb2019_inj1_type import NSB2019Inj1Type
from aind_sharepoint_service_async_client.models.nsb2019_inj2_angle import NSB2019Inj2Angle
from aind_sharepoint_service_async_client.models.nsb2019_inj2_hemisphere import NSB2019Inj2Hemisphere
from aind_sharepoint_service_async_client.models.nsb2019_inj2_retsetting import NSB2019Inj2Retsetting
from aind_sharepoint_service_async_client.models.nsb2019_inj2_round import NSB2019Inj2Round
from aind_sharepoint_service_async_client.models.nsb2019_inj2_type import NSB2019Inj2Type
from aind_sharepoint_service_async_client.models.nsb2019_iontonumberhpinj import NSB2019Iontonumberhpinj
from aind_sharepoint_service_async_client.models.nsb2019_issue import NSB2019Issue
from aind_sharepoint_service_async_client.models.nsb2019_laceration import NSB2019Laceration
from aind_sharepoint_service_async_client.models.nsb2019_light_cycle import NSB2019LightCycle
from aind_sharepoint_service_async_client.models.nsb2019_lims_project_code import NSB2019LimsProjectCode
from aind_sharepoint_service_async_client.models.nsb2019_lims_required import NSB2019LimsRequired
from aind_sharepoint_service_async_client.models.nsb2019_limstaskflow import NSB2019Limstaskflow
from aind_sharepoint_service_async_client.models.nsb2019_list import NSB2019List
from aind_sharepoint_service_async_client.models.nsb2019_previously_injected import NSB2019PreviouslyInjected
from aind_sharepoint_service_async_client.models.nsb2019_procedure import NSB2019Procedure
from aind_sharepoint_service_async_client.models.nsb2019_project_id import NSB2019ProjectId
from aind_sharepoint_service_async_client.models.nsb2019_scabbing import NSB2019Scabbing
from aind_sharepoint_service_async_client.models.nsb2019_second_round_inj_iso_level import NSB2019SecondRoundInjIsoLevel
from aind_sharepoint_service_async_client.models.nsb2019_second_round_ionto_issue import NSB2019SecondRoundIontoIssue
from aind_sharepoint_service_async_client.models.nsb2019_second_round_workstation import NSB2019SecondRoundWorkstation
from aind_sharepoint_service_async_client.models.nsb2019_secondroundiontonumber import NSB2019Secondroundiontonumber
from aind_sharepoint_service_async_client.models.nsb2019_secondroundnanojectnumber import NSB2019Secondroundnanojectnumber
from aind_sharepoint_service_async_client.models.nsb2019_sex import NSB2019Sex
from aind_sharepoint_service_async_client.models.nsb2019_sinus_bleed import NSB2019SinusBleed
from aind_sharepoint_service_async_client.models.nsb2019_surgery_status import NSB2019SurgeryStatus
from aind_sharepoint_service_async_client.models.nsb2019_touch_up_status import NSB2019TouchUpStatus
from aind_sharepoint_service_async_client.models.nsb2019_window_clarity import NSB2019WindowClarity
from aind_sharepoint_service_async_client.models.nsb2023_aind_project_name import NSB2023AindProjectName
from aind_sharepoint_service_async_client.models.nsb2023_behavior import NSB2023Behavior
from aind_sharepoint_service_async_client.models.nsb2023_behavior_autotrain_curriculum import NSB2023BehaviorAutotrainCurriculum
from aind_sharepoint_service_async_client.models.nsb2023_behavior_curriculum_version import NSB2023BehaviorCurriculumVersion
from aind_sharepoint_service_async_client.models.nsb2023_behavior_destination import NSB2023BehaviorDestination
from aind_sharepoint_service_async_client.models.nsb2023_behavior_fiber_photometry import NSB2023BehaviorFiberPhotometry
from aind_sharepoint_service_async_client.models.nsb2023_behavior_fip_mode import NSB2023BehaviorFipMode
from aind_sharepoint_service_async_client.models.nsb2023_behavior_first_fip_stage import NSB2023BehaviorFirstFipStage
from aind_sharepoint_service_async_client.models.nsb2023_behavior_first_video_recording_stage import NSB2023BehaviorFirstVideoRecordingStage
from aind_sharepoint_service_async_client.models.nsb2023_behavior_platform import NSB2023BehaviorPlatform
from aind_sharepoint_service_async_client.models.nsb2023_behavior_type import NSB2023BehaviorType
from aind_sharepoint_service_async_client.models.nsb2023_black_cement import NSB2023BlackCement
from aind_sharepoint_service_async_client.models.nsb2023_burr1_fiber_type import NSB2023Burr1FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr1_hemisphere import NSB2023Burr1Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr1_injection_device import NSB2023Burr1InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_ccf_target import NSB2023Burr1IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_blue import NSB2023Burr1IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_green import NSB2023Burr1IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_isosbestic import NSB2023Burr1IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_red import NSB2023Burr1IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr1_perform_during import NSB2023Burr1PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr1_spinal_location import NSB2023Burr1SpinalLocation
from aind_sharepoint_service_async_client.models.nsb2023_burr1_status import NSB2023Burr1Status
from aind_sharepoint_service_async_client.models.nsb2023_burr1_virus_biosaftey_level_bsl import NSB2023Burr1VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr2_fiber_type import NSB2023Burr2FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr2_hemisphere import NSB2023Burr2Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr2_injection_device import NSB2023Burr2InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_ccf_target import NSB2023Burr2IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_blue import NSB2023Burr2IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_green import NSB2023Burr2IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_isosbestic import NSB2023Burr2IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_red import NSB2023Burr2IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr2_perform_during import NSB2023Burr2PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr2_spinal_location import NSB2023Burr2SpinalLocation
from aind_sharepoint_service_async_client.models.nsb2023_burr2_status import NSB2023Burr2Status
from aind_sharepoint_service_async_client.models.nsb2023_burr2_virus_biosaftey_level_bsl import NSB2023Burr2VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr3_fiber_type import NSB2023Burr3FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr3_hemisphere import NSB2023Burr3Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr3_injection_device import NSB2023Burr3InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_ccf_target import NSB2023Burr3IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_blue import NSB2023Burr3IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_green import NSB2023Burr3IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_isosbestic import NSB2023Burr3IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_red import NSB2023Burr3IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr3_perform_during import NSB2023Burr3PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr3_status import NSB2023Burr3Status
from aind_sharepoint_service_async_client.models.nsb2023_burr3_virus_biosafety_level_bsl import NSB2023Burr3VirusBiosafetyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr4_fiber_type import NSB2023Burr4FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr4_hemisphere import NSB2023Burr4Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr4_injection_device import NSB2023Burr4InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_ccf_target import NSB2023Burr4IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_blue import NSB2023Burr4IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_green import NSB2023Burr4IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_isosbestic import NSB2023Burr4IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_red import NSB2023Burr4IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr4_perform_during import NSB2023Burr4PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr4_status import NSB2023Burr4Status
from aind_sharepoint_service_async_client.models.nsb2023_burr4_virus_biosaftey_level_bsl import NSB2023Burr4VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr5_fiber_type import NSB2023Burr5FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr5_hemisphere import NSB2023Burr5Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr5_injection_device import NSB2023Burr5InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_ccf_target import NSB2023Burr5IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_blue import NSB2023Burr5IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_green import NSB2023Burr5IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_isosbestic import NSB2023Burr5IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_red import NSB2023Burr5IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr5_perform_during import NSB2023Burr5PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr5_status import NSB2023Burr5Status
from aind_sharepoint_service_async_client.models.nsb2023_burr5_virus_biosaftey_level_bsl import NSB2023Burr5VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr6_fiber_type import NSB2023Burr6FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr6_hemisphere import NSB2023Burr6Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr6_injection_device import NSB2023Burr6InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_ccf_target import NSB2023Burr6IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_blue import NSB2023Burr6IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_green import NSB2023Burr6IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_isosbestic import NSB2023Burr6IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_red import NSB2023Burr6IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr6_perform_during import NSB2023Burr6PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr6_status import NSB2023Burr6Status
from aind_sharepoint_service_async_client.models.nsb2023_burr6_virus_biosaftey_level_bsl import NSB2023Burr6VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole1 import NSB2023BurrHole1
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole2 import NSB2023BurrHole2
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole3 import NSB2023BurrHole3
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole4 import NSB2023BurrHole4
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole5 import NSB2023BurrHole5
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole6 import NSB2023BurrHole6
from aind_sharepoint_service_async_client.models.nsb2023_care_moduele import NSB2023CareModuele
from aind_sharepoint_service_async_client.models.nsb2023_contusion_hematoma import NSB2023ContusionHematoma
from aind_sharepoint_service_async_client.models.nsb2023_craniotomy_perform_during import NSB2023CraniotomyPerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_craniotomy_type import NSB2023CraniotomyType
from aind_sharepoint_service_async_client.models.nsb2023_edema_swelling import NSB2023EdemaSwelling
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant1_length import NSB2023FiberImplant1Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant2_length import NSB2023FiberImplant2Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant3_length import NSB2023FiberImplant3Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant4_length import NSB2023FiberImplant4Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant5_length import NSB2023FiberImplant5Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant6_length import NSB2023FiberImplant6Length
from aind_sharepoint_service_async_client.models.nsb2023_follow_up_nanoject_number import NSB2023FollowUpNanojectNumber
from aind_sharepoint_service_async_client.models.nsb2023_follow_up_workstation import NSB2023FollowUpWorkstation
from aind_sharepoint_service_async_client.models.nsb2023_folow_up_ionto_number import NSB2023FolowUpIontoNumber
from aind_sharepoint_service_async_client.models.nsb2023_headpost import NSB2023Headpost
from aind_sharepoint_service_async_client.models.nsb2023_headpost_perform_during import NSB2023HeadpostPerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_iacuc_protocol import NSB2023IacucProtocol
from aind_sharepoint_service_async_client.models.nsb2023_implant_id_coverslip_type import NSB2023ImplantIdCoverslipType
from aind_sharepoint_service_async_client.models.nsb2023_initial_ionto_number import NSB2023InitialIontoNumber
from aind_sharepoint_service_async_client.models.nsb2023_initial_nanoject_number import NSB2023InitialNanojectNumber
from aind_sharepoint_service_async_client.models.nsb2023_initial_work_station import NSB2023InitialWorkStation
from aind_sharepoint_service_async_client.models.nsb2023_inj1_retsetting import NSB2023Inj1Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj1_type import NSB2023Inj1Type
from aind_sharepoint_service_async_client.models.nsb2023_inj2_retsetting import NSB2023Inj2Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj2_type import NSB2023Inj2Type
from aind_sharepoint_service_async_client.models.nsb2023_inj3_retsetting import NSB2023Inj3Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj3_type import NSB2023Inj3Type
from aind_sharepoint_service_async_client.models.nsb2023_inj4_retsetting import NSB2023Inj4Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj4_type import NSB2023Inj4Type
from aind_sharepoint_service_async_client.models.nsb2023_inj5_retsetting import NSB2023Inj5Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj5_type import NSB2023Inj5Type
from aind_sharepoint_service_async_client.models.nsb2023_inj6_retsetting import NSB2023Inj6Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj6_type import NSB2023Inj6Type
from aind_sharepoint_service_async_client.models.nsb2023_laceration import NSB2023Laceration
from aind_sharepoint_service_async_client.models.nsb2023_lims_project import NSB2023LimsProject
from aind_sharepoint_service_async_client.models.nsb2023_lims_required import NSB2023LimsRequired
from aind_sharepoint_service_async_client.models.nsb2023_lims_taskflow import NSB2023LimsTaskflow
from aind_sharepoint_service_async_client.models.nsb2023_list import NSB2023List
from aind_sharepoint_service_async_client.models.nsb2023_of_burr_holes import NSB2023OfBurrHoles
from aind_sharepoint_service_async_client.models.nsb2023_physiology_type import NSB2023PhysiologyType
from aind_sharepoint_service_async_client.models.nsb2023_procedure import NSB2023Procedure
from aind_sharepoint_service_async_client.models.nsb2023_procedure_category import NSB2023ProcedureCategory
from aind_sharepoint_service_async_client.models.nsb2023_procedure_slots import NSB2023ProcedureSlots
from aind_sharepoint_service_async_client.models.nsb2023_project_id import NSB2023ProjectId
from aind_sharepoint_service_async_client.models.nsb2023_protocol import NSB2023Protocol
from aind_sharepoint_service_async_client.models.nsb2023_sex import NSB2023Sex
from aind_sharepoint_service_async_client.models.nsb2023_sinus_bleed import NSB2023SinusBleed
from aind_sharepoint_service_async_client.models.nsb2023_surgery_status import NSB2023SurgeryStatus
from aind_sharepoint_service_async_client.models.nsb2023_thermistor import NSB2023Thermistor
from aind_sharepoint_service_async_client.models.nsb2023_well import NSB2023Well
from aind_sharepoint_service_async_client.models.validation_error import ValidationError
from aind_sharepoint_service_async_client.models.validation_error_loc_inner import ValidationErrorLocInner



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.nsb2023_list import NSB2023List

class TestNSB2023List(unittest.TestCase):
    """NSB2023List unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NSB2023List:
        """Test NSB2023List
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NSB2023List`
        """
        model = NSB2023List()
        if include_optional:
            return NSB2023List(
                age_x0020_at_x0020_injection = '',
                aind_x0020_project_x0020_name = 'Brain Wide Circuit Dynamics',
                ap2nd_inj = 1.337,
                app_author = 56,
                app_editor = '',
                attachments = True,
                author = '',
                author_id = 56,
                author_lookup_id = 56,
                editor_id = 56,
                editor_lookup_id = 56,
                test1_lookup_id = 56,
                test_x0020_1st_x0020_round_x0020_lookup_id = 56,
                behavior = 'No',
                behavior_x0020_autotrain_x0020_c = 'Coupled Baiting',
                behavior_x0020_complete = '',
                behavior_x0020_curriculum_x0020_ = '2.3',
                behavior_x0020_destination = 'Ephys',
                behavior_x0020_fiber_x0020_photo = 'Yes',
                behavior_x0020_first_x0020_video = '1.1',
                behavior_x0020_first_x0020_fip_x = '1.1',
                behavior_x0020_platform = 'Mindscope',
                behavior_x0020_type = 'Select...',
                behavior_x0020_fip_x0020_mode = 'N/A',
                black_x0020_cement = 'Yes',
                breg2_lamb = 1.337,
                burr1_x0020_injection_x0020_devi = 'Select...',
                burr1_x0020_perform_x0020_during = 'Initial Surgery',
                burr1_x0020_virus_x0020_biosafte = 'Select...',
                burr2_x0020_injection_x0020_devi = 'Select...',
                burr2_x0020_perform_x0020_during = 'Initial Surgery',
                burr2_x0020_status = 'Complete',
                burr2_x0020_virus_x0020_biosafte = 'Select...',
                burr3_x0020_injection_x0020_devi = 'Select...',
                burr3_x0020_perform_x0020_during = 'Initial Surgery',
                burr3_x0020_status = 'Complete',
                burr3_x0020_virus_x0020_biosafet = 'Select...',
                burr3_x0020_a_x002f_p = 1.337,
                burr3_x0020_d_x002f_v = 1.337,
                burr3_x0020_m_x002f_l = 1.337,
                burr4_x0020_injection_x0020_devi = 'Select...',
                burr4_x0020_perform_x0020_during = 'Initial Surgery',
                burr4_x0020_status = 'Complete',
                burr4_x0020_virus_x0020_biosafte = 'Select...',
                burr4_x0020_a_x002f_p = 1.337,
                burr4_x0020_d_x002f_v = 1.337,
                burr4_x0020_m_x002f_l = 1.337,
                burr5_x0020_injection_x0020_devi = 'Select...',
                burr5_x0020_perform_x0020_during = 'Initial Surgery',
                burr5_x0020_status = 'Complete',
                burr5_x0020_virus_x0020_biosafte = 'Select...',
                burr6_x0020_injection_x0020_devi = 'Select...',
                burr6_x0020_perform_x0020_during = 'Initial Surgery',
                burr6_x0020_status = 'Complete',
                burr6_x0020_virus_x0020_biosafte = 'Select...',
                burr_x0020_1_x0020_fiber_x0020_t = 'Standard (provided by NSB)',
                burr_x0020_1_x0020_grid_x0020_sp = 1.337,
                burr_x0020_1_x0020_injectable_x00 = '',
                burr_x0020_1_x0020_injectable_x01 = '',
                burr_x0020_1_x0020_injectable_x02 = '',
                burr_x0020_1_x0020_injectable_x03 = '',
                burr_x0020_1_x0020_injectable_x04 = '',
                burr_x0020_1_x0020_injectable_x05 = '',
                burr_x0020_1_x0020_injectable_x06 = '',
                burr_x0020_1_x0020_injectable_x0 = '',
                burr_x0020_1_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_1_x0020_spinal_x0020_ = 'Select...',
                burr_x0020_1_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_1_x0020_dv_x0020_2 = 1.337,
                burr_x0020_1_x0020_intended_x0020 = 'N/A',
                burr_x0020_1_x0020_intended_x0021 = 'N/A',
                burr_x0020_1_x0020_intended_x0022 = 'N/A',
                burr_x0020_1_x0020_intended_x0023 = 'N/A',
                burr_x0020_2_x0020_fiber_x0020_t = 'Standard (Provided by NSB)',
                burr_x0020_2_x0020_injectable_x00 = '',
                burr_x0020_2_x0020_injectable_x01 = '',
                burr_x0020_2_x0020_injectable_x02 = '',
                burr_x0020_2_x0020_injectable_x03 = '',
                burr_x0020_2_x0020_injectable_x04 = '',
                burr_x0020_2_x0020_injectable_x05 = '',
                burr_x0020_2_x0020_injectable_x06 = '',
                burr_x0020_2_x0020_injectable_x0 = '',
                burr_x0020_2_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_2_x0020_spinal_x0020_ = 'Select...',
                burr_x0020_2_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_2_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_2_x0020_intended_x0020 = 'N/A',
                burr_x0020_2_x0020_intended_x0021 = 'N/A',
                burr_x0020_2_x0020_intended_x0022 = 'N/A',
                burr_x0020_2_x0020_intended_x0023 = 'N/A',
                burr_x0020_3_x0020_angle = 1.337,
                burr_x0020_3_x0020_fiber_x0020_t = 'Standard (Provided by NSB)',
                burr_x0020_3_x0020_hemisphere = 'Select...',
                burr_x0020_3_x0020_injectable_x00 = '',
                burr_x0020_3_x0020_injectable_x01 = '',
                burr_x0020_3_x0020_injectable_x02 = '',
                burr_x0020_3_x0020_injectable_x03 = '',
                burr_x0020_3_x0020_injectable_x04 = '',
                burr_x0020_3_x0020_injectable_x05 = '',
                burr_x0020_3_x0020_injectable_x06 = '',
                burr_x0020_3_x0020_injectable_x0 = '',
                burr_x0020_3_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_3_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_3_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_3_x0020_intended_x0020 = 'N/A',
                burr_x0020_3_x0020_intended_x0021 = 'N/A',
                burr_x0020_3_x0020_intended_x0022 = 'N/A',
                burr_x0020_3_x0020_intended_x0023 = 'N/A',
                burr_x0020_4_x0020_angle = 1.337,
                burr_x0020_4_x0020_fiber_x0020_t = 'Standard (Provided by NSB)',
                burr_x0020_4_x0020_hemisphere = 'Select...',
                burr_x0020_4_x0020_injectable_x00 = '',
                burr_x0020_4_x0020_injectable_x01 = '',
                burr_x0020_4_x0020_injectable_x02 = '',
                burr_x0020_4_x0020_injectable_x03 = '',
                burr_x0020_4_x0020_injectable_x04 = '',
                burr_x0020_4_x0020_injectable_x05 = '',
                burr_x0020_4_x0020_injectable_x06 = '',
                burr_x0020_4_x0020_injectable_x0 = '',
                burr_x0020_4_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_4_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_4_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_4_x0020_intended_x0020 = 'N/A',
                burr_x0020_4_x0020_intended_x0021 = 'N/A',
                burr_x0020_4_x0020_intended_x0022 = 'N/A',
                burr_x0020_4_x0020_intended_x0023 = 'N/A',
                burr_x0020_5_x0020_angle = 1.337,
                burr_x0020_5_x0020_fiber_x0020_t = 'Standard (provided by NSB)',
                burr_x0020_5_x0020_hemisphere = 'Select...',
                burr_x0020_5_x0020_injectable_x00 = '',
                burr_x0020_5_x0020_injectable_x01 = '',
                burr_x0020_5_x0020_injectable_x02 = '',
                burr_x0020_5_x0020_injectable_x03 = '',
                burr_x0020_5_x0020_injectable_x04 = '',
                burr_x0020_5_x0020_injectable_x05 = '',
                burr_x0020_5_x0020_injectable_x06 = '',
                burr_x0020_5_x0020_injectable_x0 = '',
                burr_x0020_5_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_5_x0020_a_x002f_p = 1.337,
                burr_x0020_5_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_5_x0020_d_x002f_v_x001 = 1.337,
                burr_x0020_5_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_5_x0020_intended_x0020 = 'N/A',
                burr_x0020_5_x0020_intended_x0021 = 'N/A',
                burr_x0020_5_x0020_intended_x0022 = 'N/A',
                burr_x0020_5_x0020_intended_x0023 = 'N/A',
                burr_x0020_5_x0020_m_x002f_l = 1.337,
                burr_x0020_6_x0020_angle = 1.337,
                burr_x0020_6_x0020_fiber_x0020_t = 'Standard (provided by NSB)',
                burr_x0020_6_x0020_hemisphere = 'Select...',
                burr_x0020_6_x0020_injectable_x00 = '',
                burr_x0020_6_x0020_injectable_x01 = '',
                burr_x0020_6_x0020_injectable_x02 = '',
                burr_x0020_6_x0020_injectable_x03 = '',
                burr_x0020_6_x0020_injectable_x04 = '',
                burr_x0020_6_x0020_injectable_x05 = '',
                burr_x0020_6_x0020_injectable_x06 = '',
                burr_x0020_6_x0020_injectable_x0 = '',
                burr_x0020_6_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_6_x0020_a_x002f_p = 1.337,
                burr_x0020_6_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_6_x0020_d_x002f_v_x001 = 1.337,
                burr_x0020_6_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_6_x0020_intended_x0020 = 'N/A',
                burr_x0020_6_x0020_intended_x0021 = 'N/A',
                burr_x0020_6_x0020_intended_x0022 = 'N/A',
                burr_x0020_6_x0020_intended_x0023 = 'N/A',
                burr_x0020_6_x0020_m_x002f_l = 1.337,
                burr_x0020_hole_x0020_1_x0020_st = 'Complete',
                burr_x0020_hole_x0020_1 = 'Select...',
                burr_x0020_hole_x0020_2 = 'Select...',
                burr_x0020_hole_x0020_3 = 'Select...',
                burr_x0020_hole_x0020_4 = 'Select...',
                burr_x0020_hole_x0020_5 = 'Select...',
                burr_x0020_hole_x0020_6 = 'Select...',
                care_x0020_moduele = 'Select...',
                color_tag = '',
                com_coplanar = 'Select...',
                com_sinusbleed = 'Select...',
                com_swelling = 'Select...',
                compliance_asset_id = '',
                content_type = '',
                contusion = 'Select...',
                craniotomy_x0020_perform_x0020_d = 'Follow up Surgery',
                craniotomy_type = 'Select...',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date1st_injection = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_x0020_of_x0020_birth = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_x0020_of_x0020_surgery = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_range_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                doc_icon = '',
                dv2nd_inj = 1.337,
                edit = '',
                editor = '',
                fiber_x0020_implant1_x0020_lengt = 'Select...',
                fiber_x0020_implant2_x0020_lengt = 'Select...',
                fiber_x0020_implant3_x0020_lengt = 'Select...',
                fiber_x0020_implant3_x0020_d_x00 = 1.337,
                fiber_x0020_implant4_x0020_lengt = 'Select...',
                fiber_x0020_implant4_x0020_d_x00 = 1.337,
                fiber_x0020_implant5_x0020_lengt = 'Select...',
                fiber_x0020_implant5_x0020_d_x00 = 1.337,
                fiber_x0020_implant6_x0020_lengt = 'Select...',
                fiber_x0020_implant6_x0020_d_x00 = 1.337,
                fiber_implant1_dv = 1.337,
                fiber_implant2_dv = 1.337,
                first_inj_recovery = 1.337,
                first_injection_iso_duration = 1.337,
                first_injection_weight_after = 1.337,
                first_injection_weight_befor = 1.337,
                folder_child_count = '',
                headpost = 'Select...',
                headpost_x0020_perform_x0020_dur = 'Follow up Surgery',
                headpost_type = 'Select...',
                hemisphere2nd_inj = 'Select...',
                hp_iso_level = 1.337,
                hp_recovery = 1.337,
                hp_surgeon_comments = '',
                hp_work_station = 'Select...',
                iacuc_x0020_protocol_x0020__x002 = 'Select...',
                id = 1.337,
                implant_id_coverslip_type = 'Select...',
                inj1_alternating_time = '',
                inj1_angle_v2 = 1.337,
                inj1_current = '',
                inj1_ionto_time = '',
                inj1_storage_location = '',
                inj1_type = 'Select...',
                inj1_virus_strain_rt = '',
                inj1volperdepth = 1.337,
                inj2_alternating_time = '',
                inj2_angle_v2 = 1.337,
                inj2_current = '',
                inj2_ionto_time = '',
                inj2_storage_location = '',
                inj2_type = 'Select...',
                inj2_virus_strain_rt = '',
                inj2volperdepth = 1.337,
                inj3_alternating_time = '',
                inj3_current = '',
                inj3_ionto_time = '',
                inj3_storage_location = '',
                inj3_type = 'Select...',
                inj3ret_setting = 'Off',
                inj3volperdepth = 1.337,
                inj4_alternating_time = '',
                inj4_current = '',
                inj4_ionto_time = '',
                inj4_storage_location = '',
                inj4_type = 'Select...',
                inj4_virus_strain_rt = '',
                inj4ret_setting = 'Off',
                inj4volperdepth = 1.337,
                inj5_alternating_time = '',
                inj5_current = '',
                inj5_ionto_time = '',
                inj5_storage_location = '',
                inj5_type = 'Select...',
                inj5_virus_strain_rt = '',
                inj5ret_setting = 'Off',
                inj5volperdepth = 1.337,
                inj6_alternating_time = '',
                inj6_current = '',
                inj6_ionto_time = '',
                inj6_storage_location = '',
                inj6_type = 'Select...',
                inj6_virus_strain_rt = '',
                inj6ret_setting = 'Off',
                inj6volperdepth = 1.337,
                inj_virus_strain_rt = '',
                ionto_number_inj1 = 'Select...',
                ionto_number_inj2 = 'Select...',
                is_record = '',
                iso_x0020_on = 1.337,
                item_child_count = '',
                lab_tracks_x0020_group = '',
                lab_tracks_x0020_requestor = '',
                lab_tracks_x0020_id1 = '',
                lims_x0020_required = 'Select...',
                light_cycle = 'Standard Light Cycle (6am to 8pm light)',
                lims_project = '0200',
                lims_taskflow = 'AIND Ephys (Surgery only)',
                link_title = '',
                link_title_no_menu = '',
                long_requestor_comments = '',
                ml2nd_inj = 1.337,
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                nanoject_number_inj10 = 'Select...',
                nanoject_number_inj2 = 'Select...',
                non_x002d_nsb_x0020_surgeon = True,
                x0023__x0020_of_x0020_burr_x002 = 'Select...',
                pedigree_name = '',
                pi = '',
                procedure = 'Select...',
                procedure_x0020_family = 'Select...',
                procedure_x0020_slots = 'Select...',
                procedure_x0020_t2 = 'Select...',
                project_id = '101-03-001-10 Costa PGA Lab Research (Direct)',
                protocol = 'Select...',
                ret_setting0 = 'Off',
                ret_setting1 = 'Off',
                round1_inj_isolevel = 1.337,
                sex = 'Select...',
                surgery_status = 'Injection Pending',
                test1 = '',
                test_x0020_1st_x0020_round_x0020 = '',
                thermistor = 'No',
                title = '',
                ui_version_string = '',
                virus_x0020_hemisphere = 'Select...',
                virus_x0020_a_x002f_p = 1.337,
                virus_x0020_d_x002f_v = 1.337,
                virus_x0020_m_x002f_l = 1.337,
                weight_x0020_after_x0020_surgery = 1.337,
                weight_x0020_before_x0020_surger = 1.337,
                work_station1st_injection = 'Select...'
            )
        else:
            return NSB2023List(
        )
        """

    def testNSB2023List(self):
        """Test NSB2023List"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019ProjectId(str, Enum):
    """
    Enum class for ProjectId
    """

    """
    allowed enum values
    """
    CAMC506 = 'CAM-C506'
    CONT503 = 'CON-T503'
    CTYT504 = 'CTY-T504'
    LOCC500 = 'LOC-C500'
    N_1020100910_CTY_MORPHOLO = '102-01-009-10: CTY-Morphology'
    N_1020101010_CTY_SYNAPTIC = '102-01-010-10: CTY-Synaptic Phys'
    N_1020101410_CTY_GEN_TOOL = '102-01-014-10: CTY GenTools Mouse'
    N_1020102120_CTYBRAIN_001 = '102-01-021-20: CTY-BRAIN Mouse Brain Cell Atlas Seg 1'
    N_1020102120_CTYBRAIN_MOU = '102-01-021-20: CTY-BRAIN Mouse Brain Cell Atlas Seg 2 Anatomy'
    N_1020103620_DISSEMINATIO = '102-01-036-20 Dissemination of 3-photon Imaging'
    N_1020104320_OPTICAL_INTE = '102-01-043-20 Optical Interrogation of Venular Function'
    N_1020104410_CTY_GENOMICS = '102-01-044-10 CTY Genomics'
    N_1020104510_IVSCC = '102-01-045-10 IVSCC'
    N_1020104720_3_P_NHP_CORT = '102-01-047-20 3P NHP cortical imaging R34'
    N_1020104810_CTY_BARCODED = '102-01-048-10 CTY Barcoded Connectomics'
    N_1020105520_CTY_EM_MOTOR = '102-01-055-20 CTY EM Motor Cortex'
    N_1020199910_CTY_PROGRAM = '102-01-999-10 CTY Program Admin'
    N_1020201220_BRAIN_VIRAL = '102-02-012-20: BRAIN Viral Strategies'
    N_1020201720_BRAIN_NEUROP = '102-02-017-20 BRAIN Neuropixels Ultra'
    N_1020400620_OTH_MEASURIN = '102-04-006-20: OTH Measuring Consciousness'
    N_1020400710_TARGETED_CNS = '102-04-007-10 Targeted CNS Gene Therapy'
    N_1020401010_CTY_SR_SLC6 = '102-04-010-10 CTY SR: SLC6A1'
    N_1020401410_CTY_PARKINSO = '102-04-014-10 CTY Parkinsons Disease'
    N_1028800410_XPG_CORE_001 = '102-88-004-10 XPG Core Virus Prod, Task: CVS Production'
    N_1028800410_XPG_CORE_VIR = '102-88-004-10 XPG Core Virus Prod, Task: R&D'
    N_1210100410_VIP_REGULATE = '121-01-004-10 VIP Regulated Stabilized Networks'
    N_1210100710_TASK_TRAINED = '121-01-007-10 Task Trained Networks'
    N_1210100810_NEURAL_ENSEM = '121-01-008-10 Neural Ensemble Variability'
    N_1210101010_V1_OM_FISH = '121-01-010-10 V1 omFISH'
    N_1210101110_DYNAMIC_ROUT = '121-01-011-10 Dynamic Routing'
    N_1210101210_LEARNING_M_F = '121-01-012-10 Learning mFISH'
    N_1210101320_MSP_TEMPLETO = '121-01-013-20 MSP Templeton'
    N_1210101620_BRAIN_OPEN_S = '121-01-016-20 BRAIN OpenScope'
    N_1210102320_MSP_TEMPLETO = '121-01-023-20 MSP Templeton - Testing Theories of Consciousness'
    N_1210199910_MINDSCOPE_MS = '121-01-999-10 Mindscope (MSP) Cross Program'
    N_1220100110_NEURAL_DYNAM = '122-01-001-10 Neural Dynamics Scientific Activities'
    N_1220100220_NEURAL_DYNAM = '122-01-002-20 Neural Dynamics U19- Project 1: Period 1'
    N_1220100220_NEURAL_D_001 = '122-01-002-20 Neural Dynamics U19- Project 2: Period 1'
    N_1229999910_NEURAL_DYNAM = '122-99-999-10 Neural Dynamics Admin (Direct)'
    SELECT = 'Select...'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019ProjectId from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASTcprep(str, Enum):
    """
    Enum class for TCPrep.
    """

    """
    allowed enum values
    """
    FRESH_BRAIN_DISSECTION = 'Fresh Brain Dissection (SOP AF0061)'
    MOUSE_CARDIAC_PERFUSION = 'Mouse Cardiac Perfusion (SOP AF0075)'
    ACSF_PERFUSION = 'ACSF Perfusion'
    MOUSE_BRAIN_PERFUSION_A = 'Mouse Brain Perfusion and Flash Freezing Protocol (SOP AF0138)'
    EMBRYO_COLLECTION = 'Embryo Collection'
    MOUSE_CARDIAC_PERFUSION_2 = 'Mouse Cardiac Perfusion and Brain Hemisphere Processing for Viral Genetic Tools Pipeline (SOP AF0140)'
    MOUSE_CARDIAC_PERFUSION_3 = 'Mouse Cardiac Perfusion with Gel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASTcprep from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019Issue(str, Enum):
    """
    Enum class for Issue
    """

    """
    allowed enum values
    """
    EXUDATE = 'Exudate'
    EYE_ISSUE = 'Eye Issue'
    METABOND = 'Metabond'
    MULTIPLE_ISSUES_NOTES_IN = 'Multiple Issues (Notes In comments)'
    NON_SURGICAL_ISSUE = 'Non-Surgical Issue'
    OTHERWRITE_IN_COMMENTS = 'Other..(write in comments)'
    REPLACEMENT_COVERSLIP = 'Replacement: Coverslip'
    REPLACEMENT_KWIKCAST = 'Replacement: Kwikcast'
    REPLACEMENT_ORING = 'Replacement: O-ring'
    SCABBING = 'Scabbing'
    SELECT = 'Select...'
    Z_MOTION = 'Z-Motion'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019Issue from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019LimsProjectCode(str, Enum):
    """
    Enum class for LimsProjectCode
    """

    """
    allowed enum values
    """
    AINDDISCOVERY = 'aind-discovery'
    AINDEPHYS = 'aind-ephys'
    AINDMSMA = 'aind-msma'
    AINDOPHYS = 'aind-ophys'
    BRAINTV_VIRAL_STRATEGIES = 'BraintvViralStrategies'
    CELLTYPES_TRANSGENIC_CHAR = 'CelltypesTransgenicCharacterizationGCaMP'
    CITRICACIDPILOT = 'Citricacidpilot'
    DYNAMIC_ROUTING_BEHAVIOR = 'DynamicRoutingBehaviorDev'
    DYNAMIC_ROUTING_SURGICAL = 'DynamicRoutingSurgicalDevelopment'
    DYNAMIC_ROUTING_TASK1_PRO = 'DynamicRoutingTask1Production'
    DYNAMIC_ROUTING_ULTRA_OPT = 'DynamicRoutingUltraOptotaggingBehavior'
    IS_IX = 'ISIx'
    LEARNINGM_FISH_DEVELOPMEN = 'LearningmFISHDevelopment'
    LEARNINGM_FISH_TASK1_A = 'LearningmFISHTask1A'
    MINDSCOPE_TRANSGENIC_CHAR = 'MindscopeTransgenicCharacterizationGCaMP'
    MOUSE_BRAIN_CELL_ATLAS_TR = 'MouseBrainCellAtlasTranssynaptic'
    MOUSE_GENETIC_TOOLS_PROJE = 'MouseGeneticToolsProjectionMapping'
    M_IVSCCMET = 'mIVSCC-MET'
    M_IVSCCME_TX = 'mIVSCC-METx'
    M_MPATC_HX = 'mMPATCHx'
    M_M_PATCH = 'mMPatch'
    OM_FISHRO_BINJECTIONVIRUS = 'omFISHROBinjectionviruspilot'
    OM_FISH_CUX2_MESO = 'omFISHCux2Meso'
    OM_FISH_GAD2_MESO = 'omFISHGad2Meso'
    OM_FISH_GAD2_PILOT = 'omFISHGad2Pilot'
    OM_FISH_RORB_PILOT = 'omFISHRorbPilot'
    OM_FIS_HCOREGISTRATIONPIL = 'omFISHcoregistrationpilot'
    OPENSCOPE_DEVELOPMENT = 'OpenscopeDevelopment'
    OPEN_SCOPE_DENDRITE_COUPL = 'OpenScopeDendriteCoupling'
    OPEN_SCOPE_GLOBAL_LOCAL_O = 'OpenScopeGlobalLocalOddball'
    OPEN_SCOPE_ILLUSION = 'OpenScopeIllusion'
    OPEN_SCOPE_INJECTION_PILO = 'OpenScopeInjectionPilot'
    SELECT = 'Select...'
    SURGERY_X = 'SurgeryX'
    T301T = 'T301t'
    TASK_TRAINED_NETWORKS_MUL = 'TaskTrainedNetworksMultiscope'
    TASK_TRAINED_NETWORKS_NEU = 'TaskTrainedNetworksNeuropixel'
    TINY_BLUE_DOT_BEHAVIOR = 'TinyBlueDotBehavior'
    VARIABILITY_AIM1 = 'VariabilityAim1'
    VARIABILITY_AIM1_PILOT = 'VariabilityAim1Pilot'
    VARIABILITY_SPONTANEOUS = 'VariabilitySpontaneous'
    VIP_AXONAL_V1_PHASE1 = 'VipAxonalV1Phase1'
    VIP_SOMATIC_V1_MESO = 'VIPSomaticV1Meso'
    VIP_SOMATIC_V1_PHASE1 = 'VipSomaticV1Phase1'
    VIP_SOMATIC_V1_PHASE2 = 'VipSomaticV1Phase2'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019LimsProjectCode from a JSON string"""
        return cls(json.loads(json_str))


